@@ -3,7 +3,7 @@ package Specio::Constraint::ObjectCan;
 use strict;
 use warnings;
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 use B ();
 use List::Util 1.33 ();
@@ -27,12 +27,14 @@ with 'Specio::Constraint::Role::CanType';
 
         my $methods = join ', ',
             map { B::perlstring($_) } @{ $self->methods };
-        return sprintf( <<'EOF', ($val) x 2, $methods );
+        return sprintf( <<'EOF', $val, $methods );
 (
-    Scalar::Util::blessed( %s )
-    &&
-    List::Util::all { %s->can($_) } %s
-)
+    do {
+        my $v = %s;
+        Scalar::Util::blessed($v)
+            && List::Util::all { $v->can($_) } %s;
+        }
+    )
 EOF
     };
 
@@ -57,7 +59,7 @@ Specio::Constraint::ObjectCan - A class for constraints which require an object
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -100,9 +102,13 @@ L<Specio::Constraint::Role::Interface>, and L<Specio::Role::Inlinable> roles.
 
 =head1 SUPPORT
 
-Bugs may be submitted through L<https://github.com/houseabsolute/Specio/issues>.
+Bugs may be submitted at L<https://github.com/houseabsolute/Specio/issues>.
 
-I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Specio can be found at L<https://github.com/houseabsolute/Specio>.
 
 =head1 AUTHOR
 
@@ -110,10 +116,13 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dave Rolsky.
+This software is Copyright (c) 2012 - 2017 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
